import sys

import conversion
import crossplatform_ir_generation
import desugaring
import c_generation
import interpreter
import normalization
import optimization
import parsing
import tokenization

command = sys.argv[1]

source_path = sys.argv[2]

with open(source_path, 'r') as f:
    source = f.read()

tokens = tokenization.tokenize(source)
parsed = parsing.parse(tokens)
desugared = desugaring.desugar(parsed)
normalized = normalization.normalize(desugared)
converted = conversion.convert(normalized)

crossplatform_ir = crossplatform_ir_generation.generate(converted)
optimized = optimization.optimize(crossplatform_ir)

if command == 'compile':
    generated = c_generation.generate(optimized)

    assert source_path.endswith('.fur')
    destination_path = source_path + '.c'

    with open(destination_path, 'w') as f:
        f.write(generated)

elif command == 'ir':
    outputted = crossplatform_ir_generation.output(optimized)
    print(outputted)

elif command == 'interpret':
    interpreter.interpret(optimized)
